==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-runtimes-1.30.0.Final/jbpm/jbpm-flow-builder/src/test/java/org/jbpm/integrationtests/ProcessEventListenerTest.java <==
/*
 * Copyright 2010 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/*
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package org.jbpm.integrationtests;

import java.io.Reader;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.List;

import org.drools.io.ReaderResource;
import org.jbpm.process.core.context.variable.VariableScope;
import org.jbpm.process.instance.context.variable.VariableScopeInstance;
import org.jbpm.test.util.AbstractBaseTest;
import org.junit.jupiter.api.Test;
import org.kie.api.event.process.ProcessCompletedEvent;
import org.kie.api.event.process.ProcessEvent;
import org.kie.api.event.process.ProcessEventListener;
import org.kie.api.event.process.ProcessNodeLeftEvent;
import org.kie.api.event.process.ProcessNodeTriggeredEvent;
import org.kie.api.event.process.ProcessStartedEvent;
import org.kie.api.event.process.ProcessVariableChangedEvent;
import org.kie.api.io.ResourceType;
import org.kie.kogito.internal.process.runtime.KogitoProcessInstance;
import org.kie.kogito.internal.process.runtime.KogitoProcessRuntime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class ProcessEventListenerTest extends AbstractBaseTest {

    private static final Logger logger = LoggerFactory.getLogger(ProcessEventListenerTest.class);

    @Test
    public void testInternalNodeSignalEvent() {
        Reader source = new StringReader(process);
        builder.add(new ReaderResource(source), ResourceType.DRF);

        KogitoProcessRuntime kruntime = createKogitoProcessRuntime();

        final List<ProcessEvent> processEventList = new ArrayList<>();

        final ProcessEventListener listener = createProcessEventListener(processEventList);

        kruntime.getProcessEventManager().addEventListener(listener);
        KogitoProcessInstance processInstance = kruntime.startProcess("org.drools.core.event");
        assertEquals(KogitoProcessInstance.STATE_COMPLETED, processInstance.getState());
        assertEquals("MyValue", ((VariableScopeInstance) ((org.jbpm.process.instance.ProcessInstance) processInstance)
                .getContextInstance(VariableScope.VARIABLE_SCOPE)).getVariable("MyVar"));
        assertEquals(26, processEventList.size());
        for (ProcessEvent e : processEventList) {
            logger.debug(e.toString());
        }
        assertEquals("org.drools.core.event", processEventList.get(2).getProcessInstance().getProcessId());

    }

    private ProcessEventListener createProcessEventListener(final List<ProcessEvent> processEventList) {
        return new ProcessEventListener() {

            @Override
            public void afterNodeLeft(ProcessNodeLeftEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterNodeTriggered(ProcessNodeTriggeredEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterProcessCompleted(ProcessCompletedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterProcessStarted(ProcessStartedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeNodeLeft(ProcessNodeLeftEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeNodeTriggered(ProcessNodeTriggeredEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeProcessCompleted(ProcessCompletedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeProcessStarted(ProcessStartedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeVariableChanged(ProcessVariableChangedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterVariableChanged(ProcessVariableChangedEvent event) {
                processEventList.add(event);
            }
        };
    }

    private static final String process =
            "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
                    "<process xmlns=\"http://drools.org/drools-5.0/process\"\n" +
                    "         xmlns:xs=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
                    "         xs:schemaLocation=\"http://drools.org/drools-5.0/process drools-processes-5.0.xsd\"\n" +
                    "         type=\"RuleFlow\" name=\"flow\" id=\"org.drools.core.event\" package-name=\"org.drools\" version=\"1\" >\n" +
                    "\n" +
                    "  <header>\n" +
                    "    <variables>\n" +
                    "      <variable name=\"MyVar\" >\n" +
                    "        <type name=\"org.jbpm.process.core.datatype.impl.type.StringDataType\" />\n" +
                    "        <value>SomeText</value>\n" +
                    "      </variable>\n" +
                    "    </variables>\n" +
                    "  </header>\n" +
                    "\n" +
                    "  <nodes>\n" +
                    "    <start id=\"1\" name=\"Start\" />\n" +
                    "    <eventNode id=\"2\" name=\"Event\" variableName=\"MyVar\" >\n" +
                    "      <eventFilters>\n" +
                    "        <eventFilter type=\"eventType\" eventType=\"MyEvent\" />\n" +
                    "      </eventFilters>\n" +
                    "    </eventNode>\n" +
                    "    <actionNode id=\"3\" name=\"Signal Event\" >\n" +
                    "      <action type=\"expression\" dialect=\"java\" >kcontext.getProcessInstance().signalEvent(\"MyEvent\", \"MyValue\");</action>\n" +
                    "    </actionNode>\n" +
                    "    <join id=\"4\" name=\"Join\" type=\"1\" />\n" +
                    "    <end id=\"5\" name=\"End\" />\n" +
                    "  </nodes>\n" +
                    "\n" +
                    "  <connections>\n" +
                    "    <connection from=\"1\" to=\"3\" />\n" +
                    "    <connection from=\"2\" to=\"4\" />\n" +
                    "    <connection from=\"3\" to=\"4\" />\n" +
                    "    <connection from=\"4\" to=\"5\" />\n" +
                    "  </connections>\n" +
                    "\n" +
                    "</process>";

}

==> openshift-serverless-logic-1.28.0-src.zip: openshift-serverless-logic-1.28.0.GA-src/org.kie.kogito-kogito-runtimes-1.35.0.Final/jbpm/jbpm-flow-builder/src/test/java/org/jbpm/integrationtests/ProcessEventListenerTest.java <==
/*
 * Copyright 2010 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/*
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package org.jbpm.integrationtests;

import java.io.Reader;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.List;

import org.drools.io.ReaderResource;
import org.jbpm.process.core.context.variable.VariableScope;
import org.jbpm.process.instance.context.variable.VariableScopeInstance;
import org.jbpm.test.util.AbstractBaseTest;
import org.junit.jupiter.api.Test;
import org.kie.api.event.process.ProcessCompletedEvent;
import org.kie.api.event.process.ProcessEvent;
import org.kie.api.event.process.ProcessEventListener;
import org.kie.api.event.process.ProcessNodeLeftEvent;
import org.kie.api.event.process.ProcessNodeTriggeredEvent;
import org.kie.api.event.process.ProcessStartedEvent;
import org.kie.api.event.process.ProcessVariableChangedEvent;
import org.kie.api.io.ResourceType;
import org.kie.kogito.internal.process.runtime.KogitoProcessInstance;
import org.kie.kogito.internal.process.runtime.KogitoProcessRuntime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.assertj.core.api.Assertions.assertThat;

public class ProcessEventListenerTest extends AbstractBaseTest {

    private static final Logger logger = LoggerFactory.getLogger(ProcessEventListenerTest.class);

    @Test
    public void testInternalNodeSignalEvent() {
        Reader source = new StringReader(process);
        builder.add(new ReaderResource(source), ResourceType.DRF);

        KogitoProcessRuntime kruntime = createKogitoProcessRuntime();

        final List<ProcessEvent> processEventList = new ArrayList<>();

        final ProcessEventListener listener = createProcessEventListener(processEventList);

        kruntime.getProcessEventManager().addEventListener(listener);
        KogitoProcessInstance processInstance = kruntime.startProcess("org.drools.core.event");
        assertThat(processInstance.getState()).isEqualTo(KogitoProcessInstance.STATE_COMPLETED);
        assertThat(((VariableScopeInstance) ((org.jbpm.process.instance.ProcessInstance) processInstance)
                .getContextInstance(VariableScope.VARIABLE_SCOPE)).getVariable("MyVar")).isEqualTo("MyValue");
        assertThat(processEventList).hasSize(26);
        for (ProcessEvent e : processEventList) {
            logger.debug(e.toString());
        }
        assertThat(processEventList.get(2).getProcessInstance().getProcessId()).isEqualTo("org.drools.core.event");

    }

    private ProcessEventListener createProcessEventListener(final List<ProcessEvent> processEventList) {
        return new ProcessEventListener() {

            @Override
            public void afterNodeLeft(ProcessNodeLeftEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterNodeTriggered(ProcessNodeTriggeredEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterProcessCompleted(ProcessCompletedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterProcessStarted(ProcessStartedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeNodeLeft(ProcessNodeLeftEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeNodeTriggered(ProcessNodeTriggeredEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeProcessCompleted(ProcessCompletedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeProcessStarted(ProcessStartedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void beforeVariableChanged(ProcessVariableChangedEvent event) {
                processEventList.add(event);
            }

            @Override
            public void afterVariableChanged(ProcessVariableChangedEvent event) {
                processEventList.add(event);
            }
        };
    }

    private static final String process =
            "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
                    "<process xmlns=\"http://drools.org/drools-5.0/process\"\n" +
                    "         xmlns:xs=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
                    "         xs:schemaLocation=\"http://drools.org/drools-5.0/process drools-processes-5.0.xsd\"\n" +
                    "         type=\"RuleFlow\" name=\"flow\" id=\"org.drools.core.event\" package-name=\"org.drools\" version=\"1\" >\n" +
                    "\n" +
                    "  <header>\n" +
                    "    <variables>\n" +
                    "      <variable name=\"MyVar\" >\n" +
                    "        <type name=\"org.jbpm.process.core.datatype.impl.type.StringDataType\" />\n" +
                    "        <value>SomeText</value>\n" +
                    "      </variable>\n" +
                    "    </variables>\n" +
                    "  </header>\n" +
                    "\n" +
                    "  <nodes>\n" +
                    "    <start id=\"1\" name=\"Start\" />\n" +
                    "    <eventNode id=\"2\" name=\"Event\" variableName=\"MyVar\" >\n" +
                    "      <eventFilters>\n" +
                    "        <eventFilter type=\"eventType\" eventType=\"MyEvent\" />\n" +
                    "      </eventFilters>\n" +
                    "    </eventNode>\n" +
                    "    <actionNode id=\"3\" name=\"Signal Event\" >\n" +
                    "      <action type=\"expression\" dialect=\"java\" >kcontext.getProcessInstance().signalEvent(\"MyEvent\", \"MyValue\");</action>\n" +
                    "    </actionNode>\n" +
                    "    <join id=\"4\" name=\"Join\" type=\"1\" />\n" +
                    "    <end id=\"5\" name=\"End\" />\n" +
                    "  </nodes>\n" +
                    "\n" +
                    "  <connections>\n" +
                    "    <connection from=\"1\" to=\"3\" />\n" +
                    "    <connection from=\"2\" to=\"4\" />\n" +
                    "    <connection from=\"3\" to=\"4\" />\n" +
                    "    <connection from=\"4\" to=\"5\" />\n" +
                    "  </connections>\n" +
                    "\n" +
                    "</process>";

}
